Learn R Programming

rERR (version 0.1)

confint.rERR: Confidence intervals

Description

Show the confidence intervals for each parameter of the model. The likelihood ratio test ci for linear varaibles, and the Wald ci for the loglinear terms

Usage

# S3 method for rERR
confint(object, ...)

Arguments

object

an object of class rERR

for future methods

Value

a list with the confidence intervals

Examples

Run this code
# NOT RUN {
ci.rERR(fit)
# }

Run the code above in your browser using DataLab