powered by
Show the confidence intervals for each parameter of the model. The likelihood ratio test ci for linear varaibles, and the Wald ci for the loglinear terms
# S3 method for rERR confint(object, ...)
an object of class rERR
for future methods
a list with the confidence intervals
# NOT RUN { ci.rERR(fit) # }
Run the code above in your browser using DataLab