Computes the riskset for each case with the relevant variables in the formula and the stratification vars specified in strata() part of the formula.
The riskset of a case inculde the subjects that are in the cohort when the case ocurs: so a subject S belongs to the riskset R of the case that have a 'fail' at time ft,
if S_entry_time < ft <= S_exit_time.